# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2022-01-28T20:29:29.044267'

__version__ = '0.0.0'
__sha__ = '19e0ffab70830bae36fb111ddfd43e20b119d2f4'
__revision__ = '19e0ffab70830bae36fb111ddfd43e20b119d2f4'
